Index: remoting/jingle_glue/ssl_socket_adapter.h |
diff --git a/jingle/notifier/communicator/ssl_socket_adapter.h b/remoting/jingle_glue/ssl_socket_adapter.h |
similarity index 93% |
rename from jingle/notifier/communicator/ssl_socket_adapter.h |
rename to remoting/jingle_glue/ssl_socket_adapter.h |
index cdbc94e2e41fa44cdeafadc588a1b6118068eb4a..a22e2b709e59cc8ec3c90c54d85257caea7cb565 100644 |
--- a/jingle/notifier/communicator/ssl_socket_adapter.h |
+++ b/remoting/jingle_glue/ssl_socket_adapter.h |
@@ -2,8 +2,8 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef JINGLE_NOTIFIER_COMMUNICATOR_SSL_SOCKET_ADAPTER_H_ |
-#define JINGLE_NOTIFIER_COMMUNICATOR_SSL_SOCKET_ADAPTER_H_ |
+#ifndef REMOTING_JINGLE_GLUE_SSL_SOCKET_ADAPTER_H_ |
+#define REMOTING_JINGLE_GLUE_SSL_SOCKET_ADAPTER_H_ |
#include "base/scoped_ptr.h" |
#include "net/base/completion_callback.h" |
@@ -15,7 +15,7 @@ |
#include "talk/base/asyncsocket.h" |
#include "talk/base/ssladapter.h" |
-namespace notifier { |
+namespace remoting { |
class SSLSocketAdapter; |
@@ -81,7 +81,7 @@ class TransportSocket : public net::ClientSocket, public sigslot::has_slots<> { |
}; |
// This provides a talk_base::AsyncSocketAdapter interface around Chromium's |
// net::SSLClientSocket class. This allows notifier to use Chromium's SSL |
// implementation instead of OpenSSL. |
class SSLSocketAdapter : public talk_base::SSLAdapter { |
public: |
@@ -140,6 +140,6 @@ class SSLSocketAdapter : public talk_base::SSLAdapter { |
DISALLOW_COPY_AND_ASSIGN(SSLSocketAdapter); |
}; |
-} // namespace notifier |
+} // namespace remoting |
-#endif // JINGLE_NOTIFIER_COMMUNICATOR_SSL_SOCKET_ADAPTER_H_ |
+#endif // REMOTING_JINGLE_GLUE_SSL_SOCKET_ADAPTER_H_ |
@@ -81,7 +81,7 @@ class TransportSocket : public net::ClientSocket, public sigslot::has_slots<> { |
}; |
// This provides a talk_base::AsyncSocketAdapter interface around Chromium's |
-// net::SSLClientSocket class. This allows notifier to use Chromium's SSL |
+// net::SSLClientSocket class. This allows remoting to use Chromium's SSL |
// implementation instead of OpenSSL. |
class SSLSocketAdapter : public talk_base::SSLAdapter { |